@@ -9,6 +9,6 @@
  * Create the appropriate pagent from a \<frame\> node.
  * Throws Error::Read() on failure.
  */
-Pagent *load(const xmlpp::Element& node, Group *parent, const FileContext&);
+Pagent *load(const ElementWrap& node, Group *parent);
 
 #endif
