@@ -14,6 +14,8 @@ protected:
 public:
   /**
    * Create a new TextViewent.
+   * The _scale_factor is ignored if the used ghostscript supports the
+   * pngalpha device.
    * \param cachedframe
    * \param view
    * \param _scale_factor Create bitmaps this many times bigger than
@@ -24,21 +26,23 @@ public:
   ~PostscriptViewent();
   
   void set_image(const std::string& psfile);
+  void regenerate();
   
 protected:
   const Pagent* get_frame() const { return frame; }
   void set_state(State state);
-  void on_geometry_changed(Pagent*);
+  void on_geometry_changed();
 private:
-  void regenerate();
   void process_stopped(pid_t _pid, bool exited_normally, int exit_code);
+  bool regenerate_bg();
+  void stop_process();
   
   std::auto_ptr<Gnome::Canvas::Pixbuf> canvas_pixbuf;
   FrameRef frame;
   pid_t pid;
   std::string tmp_file;
   int scale_factor;
-  PixbufRef pixbuf;
+  bool redraw_requested;
 };
 
 #endif
