@@ -6,7 +6,8 @@
 #define W_SPINNER_H
 #include <gtkmm/box.h>
 #include <gtkmm/spinbutton.h>
-#include <gtkmm/optionmenu.h>
+#include <gtkmm/comboboxtext.h>
+#include <memory>
 #include "pptout/lengthunits.h"
 
 class UnitAdjustment;
@@ -20,17 +21,15 @@ public:
 	  const float _lo_value = -8000, 
 	  const float _hi_value = 8000);
   ~Spinner();
-
+  
   void limits(float low, float high);
 
-  void set_unit(const Glib::ustring &unit);
   void set(float _value);
   float get() const;
 
   Gtk::SpinButton &get_spinbutton() const { return *spinbutton; }
-  Gtk::OptionMenu &get_optionmenu() const { return *optionmenu; }
 
-  SigC::Signal0<void> signal_changed;
+  Glib::SignalProxy0<void> signal_value_changed();
 
 protected:
   /** Direct focus to the proper part of the Spinner. */
@@ -38,12 +37,15 @@ protected:
   
 private:
   Gtk::SpinButton *spinbutton;
-  Gtk::Menu *menu;
-  Gtk::OptionMenu *optionmenu;
-  UnitAdjustment *value;
+  Gtk::ComboBoxText *unitmenu;
+  std::auto_ptr<UnitAdjustment> value;
   const FUUnits *units;
 
   void on_unit_select();
+
+  // Undefined
+  Spinner(const Spinner&);
+  Spinner& operator = (const Spinner&);
 };
 
 #endif
